---
name: Bug report
about: Create a report to help us improve

---

Summary.

## Expected Result

What you expected.

## Actual Result

What happened instead.

## Reproduction Steps

```python
import pdpipe

```

## System Information


```
<paste here>
```

Please provide some basic information about your system (Python version,
operating system, &c).
